from .base import BaseCFObject


class Mapping(BaseCFObject):
    top_level_key = "Mappings"
